@@ -1,22 +1,28 @@
 package Text::Hspell;
-$Text::Hspell::VERSION = '0.0.2';
+
 use strict;
 use warnings;
 
-use Inline Python => <<'EOF';
-import HspellPy
+require DynaLoader;
 
-class HspellPyWrapper:
-    def __init__(self):
-        self._hspell = HspellPy.Hspell(linguistics=True)
+use vars qw(@ISA);
+@ISA = qw/ DynaLoader /;
 
-    def check_word(self, word):
-        return self._hspell.check_word(word);
-EOF
+our $VERSION = '0.2.0';
+
+bootstrap Text::Hspell $VERSION;
+
+use Encode qw/ encode /;
 
 sub new
 {
-    return Inline::Python::Object->new( '__main__', 'HspellPyWrapper' );
+    return proto_new();
+}
+
+sub check_word
+{
+    my ( $self, $s ) = @_;
+    return $self->check_word_internal( encode( 'iso8859-8', $s ) );
 }
 
 1;
@@ -29,7 +35,7 @@ __END__
 
 =head1 VERSION
 
-version 0.0.2
+version 0.2.0
 
 =head1 SYNOPSIS
 
@@ -61,6 +67,14 @@ Create a new speller object instance.
 Returns true if the word is spelled right and false if it is an unknown
 word.
 
+=head2 $speller->proto_new()
+
+For internal use.
+
+=head2 $speller->check_word_internal()
+
+For internal use.
+
 =head1 COPYRIGHT & LICENSE
 
 Copyright 2019 by Shlomi Fish
@@ -89,7 +103,7 @@ WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 OTHER DEALINGS IN THE SOFTWARE.
 
-=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+=for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
 
@@ -126,14 +140,6 @@ L<https://rt.cpan.org/Public/Dist/Display.html?Name=Text-Hspell>
 
 =item *
 
-AnnoCPAN
-
-The AnnoCPAN is a website that allows community annotations of Perl module documentation.
-
-L<http://annocpan.org/dist/Text-Hspell>
-
-=item *
-
 CPAN Ratings
 
 The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
